@@ -36,6 +36,7 @@ DEALINGS IN THE SOFTWARE.
 
 #include "kstartupinfo.h"
 #include "netwm_def.h"
+#include "debug_p.h"
 
 #include <QWidget>
 #include <QDateTime>
@@ -180,7 +181,7 @@ public:
 #if KWINDOWSYSTEM_HAVE_X11
           msgs(NET_STARTUP_MSG),
 #endif
-          cleanup(Q_NULLPTR),
+          cleanup(nullptr),
           flags(flags_P)
     {
     }
@@ -232,7 +233,7 @@ void KStartupInfo::Private::got_message(const QString &msg_P)
 {
 #if KWINDOWSYSTEM_HAVE_X11
 // TODO do something with SCREEN= ?
-    //qDebug() << "got:" << msg_P;
+    //qCDebug(LOG_KWINDOWSYSTEM) << "got:" << msg_P;
     QString msg = msg_P.trimmed();
     if (msg.startsWith(QLatin1String("new:"))) { // must match length below
         got_startup_info(msg.mid(4), false);
@@ -294,7 +295,7 @@ void KStartupInfo::Private::window_added(WId w_P)
     startup_t ret = check_startup_internal(w_P, &id, &data);
     switch (ret) {
     case Match:
-        //qDebug() << "new window match";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "new window match";
         break;
     case NoMatch:
         break; // nothing
@@ -326,7 +327,7 @@ void KStartupInfo::Private::new_startup_info_internal(const KStartupInfoId &id_P
         // already reported, update
         startups[ id_P ].update(data_P);
         startups[ id_P ].age = 0; // CHECKME
-        //qDebug() << "updating";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "updating";
         if (startups[ id_P ].silent() == KStartupInfo::Data::Yes
                 && !(flags & AnnounceSilenceChanges)) {
             silent_startups[ id_P ] = startups[ id_P ];
@@ -341,7 +342,7 @@ void KStartupInfo::Private::new_startup_info_internal(const KStartupInfoId &id_P
         // already reported, update
         silent_startups[ id_P ].update(data_P);
         silent_startups[ id_P ].age = 0; // CHECKME
-        //qDebug() << "updating silenced";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "updating silenced";
         if (silent_startups[ id_P ].silent() != Data::Yes) {
             startups[ id_P ] = silent_startups[ id_P ];
             silent_startups.remove(id_P);
@@ -353,7 +354,7 @@ void KStartupInfo::Private::new_startup_info_internal(const KStartupInfoId &id_P
     }
     if (uninited_startups.contains(id_P)) {
         uninited_startups[ id_P ].update(data_P);
-        //qDebug() << "updating uninited";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "updating uninited";
         if (!update_P) { // uninited finally got new:
             startups[ id_P ] = uninited_startups[ id_P ];
             uninited_startups.remove(id_P);
@@ -364,14 +365,14 @@ void KStartupInfo::Private::new_startup_info_internal(const KStartupInfoId &id_P
         return;
     }
     if (update_P) { // change: without any new: first
-        //qDebug() << "adding uninited";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "adding uninited";
         uninited_startups.insert(id_P, data_P);
     } else if (data_P.silent() != Data::Yes || flags & AnnounceSilenceChanges) {
-        //qDebug() << "adding";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "adding";
         startups.insert(id_P, data_P);
         emit q->gotNewStartup(id_P, data_P);
     } else { // new silenced, and silent shouldn't be announced
-        //qDebug() << "adding silent";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "adding silent";
         silent_startups.insert(id_P, data_P);
     }
     cleanup->start(1000);   // 1 sec
@@ -396,7 +397,7 @@ void KStartupInfo::Private::removeAllStartupInfoInternal(const KStartupInfoId &i
 {
     auto it = startups.find(id_P);
     if (it != startups.end()) {
-        //qDebug() << "removing";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "removing";
         emit q->gotRemoveStartup(it.key(), it.value());
         startups.erase(it);
         return;
@@ -441,7 +442,7 @@ void KStartupInfo::Private::remove_startup_pids(const KStartupInfoId &id_P,
     if (data_P.pids().count() == 0) {
         qFatal("data_P.pids().count() == 0");
     }
-    Data *data = NULL;
+    Data *data = nullptr;
     if (startups.contains(id_P)) {
         data = &startups[ id_P ];
     } else if (silent_startups.contains(id_P)) {
@@ -467,18 +468,14 @@ bool KStartupInfo::sendStartup(const KStartupInfoId &id_P, const KStartupInfoDat
         return false;
     }
 #if  KWINDOWSYSTEM_HAVE_X11
-    KXMessages msgs;
-    QString msg = QString::fromLatin1("new: %1 %2")
-                  .arg(id_P.d->to_text()).arg(data_P.d->to_text());
-    msg = Private::check_required_startup_fields(msg, data_P, QX11Info::appScreen());
-    //qDebug() << "sending " << msg;
-    msgs.broadcastMessage(NET_STARTUP_MSG, msg);
+    return sendStartupXcb(QX11Info::connection(), QX11Info::appScreen(), id_P, data_P);
 #else
     Q_UNUSED(data_P)
 #endif
     return true;
 }
 
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
 bool KStartupInfo::sendStartupX(Display *disp_P, const KStartupInfoId &id_P,
                                 const KStartupInfoData &data_P)
 {
@@ -490,7 +487,7 @@ bool KStartupInfo::sendStartupX(Display *disp_P, const KStartupInfoId &id_P,
                   .arg(id_P.d->to_text()).arg(data_P.d->to_text());
     msg = Private::check_required_startup_fields(msg, data_P, DefaultScreen(disp_P));
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    qDebug() << "sending " << msg;
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
 #else
@@ -499,6 +496,29 @@ bool KStartupInfo::sendStartupX(Display *disp_P, const KStartupInfoId &id_P,
     return true;
 #endif
 }
+#endif
+
+bool KStartupInfo::sendStartupXcb(xcb_connection_t *conn, int screen, const KStartupInfoId &id_P,
+                                const KStartupInfoData &data_P)
+{
+    if (id_P.isNull()) {
+        return false;
+    }
+#if KWINDOWSYSTEM_HAVE_X11
+    QString msg = QString::fromLatin1("new: %1 %2")
+                  .arg(id_P.d->to_text()).arg(data_P.d->to_text());
+    msg = Private::check_required_startup_fields(msg, data_P, screen);
+#ifdef KSTARTUPINFO_ALL_DEBUG
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
+#endif
+    return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
+#else
+    Q_UNUSED(conn)
+    Q_UNUSED(screen)
+    Q_UNUSED(data_P)
+    return true;
+#endif
+}
 
 QString KStartupInfo::Private::check_required_startup_fields(const QString &msg, const KStartupInfoData &data_P,
         int screen)
@@ -524,17 +544,14 @@ bool KStartupInfo::sendChange(const KStartupInfoId &id_P, const KStartupInfoData
         return false;
     }
 #if KWINDOWSYSTEM_HAVE_X11
-    KXMessages msgs;
-    QString msg = QString::fromLatin1("change: %1 %2")
-                  .arg(id_P.d->to_text()).arg(data_P.d->to_text());
-    //qDebug() << "sending " << msg;
-    msgs.broadcastMessage(NET_STARTUP_MSG, msg);
+    return sendChangeXcb(QX11Info::connection(), QX11Info::appScreen(), id_P, data_P);
 #else
     Q_UNUSED(data_P)
 #endif
     return true;
 }
 
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
 bool KStartupInfo::sendChangeX(Display *disp_P, const KStartupInfoId &id_P,
                                const KStartupInfoData &data_P)
 {
@@ -545,7 +562,7 @@ bool KStartupInfo::sendChangeX(Display *disp_P, const KStartupInfoId &id_P,
     QString msg = QString::fromLatin1("change: %1 %2")
                   .arg(id_P.d->to_text()).arg(data_P.d->to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    qDebug() << "sending " << msg;
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
 #else
@@ -554,6 +571,28 @@ bool KStartupInfo::sendChangeX(Display *disp_P, const KStartupInfoId &id_P,
     return true;
 #endif
 }
+#endif
+
+bool KStartupInfo::sendChangeXcb(xcb_connection_t *conn, int screen,
+                                 const KStartupInfoId &id_P, const KStartupInfoData &data_P)
+{
+    if (id_P.isNull()) {
+        return false;
+    }
+#if KWINDOWSYSTEM_HAVE_X11
+    QString msg = QString::fromLatin1("change: %1 %2")
+                  .arg(id_P.d->to_text()).arg(data_P.d->to_text());
+#ifdef KSTARTUPINFO_ALL_DEBUG
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
+#endif
+    return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
+#else
+    Q_UNUSED(conn)
+    Q_UNUSED(screen)
+    Q_UNUSED(data_P)
+    return true;
+#endif
+}
 
 bool KStartupInfo::sendFinish(const KStartupInfoId &id_P)
 {
@@ -561,14 +600,12 @@ bool KStartupInfo::sendFinish(const KStartupInfoId &id_P)
         return false;
     }
 #if KWINDOWSYSTEM_HAVE_X11
-    KXMessages msgs;
-    QString msg = QString::fromLatin1("remove: %1").arg(id_P.d->to_text());
-    //qDebug() << "sending " << msg;
-    msgs.broadcastMessage(NET_STARTUP_MSG, msg);
+    return sendFinishXcb(QX11Info::connection(), QX11Info::appScreen(), id_P);
 #endif
     return true;
 }
 
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
 bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P)
 {
     if (id_P.isNull()) {
@@ -577,7 +614,7 @@ bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P)
 #if KWINDOWSYSTEM_HAVE_X11
     QString msg = QString::fromLatin1("remove: %1").arg(id_P.d->to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    qDebug() << "sending " << msg;
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
 #else
@@ -585,17 +622,32 @@ bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P)
     return true;
 #endif
 }
+#endif
+
+bool KStartupInfo::sendFinishXcb(xcb_connection_t *conn, int screen, const KStartupInfoId &id_P)
+{
+    if (id_P.isNull()) {
+        return false;
+    }
+#if KWINDOWSYSTEM_HAVE_X11
+    QString msg = QString::fromLatin1("remove: %1").arg(id_P.d->to_text());
+#ifdef KSTARTUPINFO_ALL_DEBUG
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
+#endif
+    return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
+#else
+    Q_UNUSED(conn)
+    Q_UNUSED(screen)
+    return true;
+#endif
+}
 
 bool KStartupInfo::sendFinish(const KStartupInfoId &id_P, const KStartupInfoData &data_P)
 {
 //    if( id_P.isNull()) // id may be null, the pids and hostname matter then
 //        return false;
 #if KWINDOWSYSTEM_HAVE_X11
-    KXMessages msgs;
-    QString msg = QString::fromLatin1("remove: %1 %2")
-                  .arg(id_P.d->to_text()).arg(data_P.d->to_text());
-    //qDebug() << "sending " << msg;
-    msgs.broadcastMessage(NET_STARTUP_MSG, msg);
+    return sendFinishXcb(QX11Info::connection(), QX11Info::appScreen(), id_P, data_P);
 #else
     Q_UNUSED(id_P)
     Q_UNUSED(data_P)
@@ -603,6 +655,7 @@ bool KStartupInfo::sendFinish(const KStartupInfoId &id_P, const KStartupInfoData
     return true;
 }
 
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
 bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P,
                                const KStartupInfoData &data_P)
 {
@@ -612,7 +665,7 @@ bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P,
     QString msg = QString::fromLatin1("remove: %1 %2")
                   .arg(id_P.d->to_text()).arg(data_P.d->to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
-    qDebug() << "sending " << msg;
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
 #else
@@ -622,6 +675,28 @@ bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P,
     return true;
 #endif
 }
+#endif
+
+bool KStartupInfo::sendFinishXcb(xcb_connection_t *conn, int screen,
+                                 const KStartupInfoId &id_P, const KStartupInfoData &data_P)
+{
+//    if( id_P.isNull()) // id may be null, the pids and hostname matter then
+//        return false;
+#if KWINDOWSYSTEM_HAVE_X11
+    QString msg = QString::fromLatin1("remove: %1 %2")
+                  .arg(id_P.d->to_text()).arg(data_P.d->to_text());
+#ifdef KSTARTUPINFO_ALL_DEBUG
+    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
+#endif
+    return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
+#else
+    Q_UNUSED(conn)
+    Q_UNUSED(screen)
+    Q_UNUSED(id_P)
+    Q_UNUSED(data_P)
+    return true;
+#endif
+}
 
 void KStartupInfo::appStarted()
 {
@@ -638,8 +713,8 @@ void KStartupInfo::appStarted(const QByteArray &startup_id)
     }
 #if KWINDOWSYSTEM_HAVE_X11
     if (QX11Info::isPlatformX11() && !qgetenv("DISPLAY").isEmpty()) {  // don't rely on QX11Info::display()
-        Display *disp = XOpenDisplay(NULL);
-        if (disp != NULL) {
+        Display *disp = XOpenDisplay(nullptr);
+        if (disp != nullptr) {
             KStartupInfo::sendFinishX(disp, id);
             XCloseDisplay(disp);
         }
@@ -704,7 +779,7 @@ void KStartupInfo::setNewStartupId(QWidget *window, const QByteArray &startup_id
     bool activate = true;
     setStartupId(startup_id);
 #if KWINDOWSYSTEM_HAVE_X11
-    if (window != NULL && QX11Info::isPlatformX11()) {
+    if (window != nullptr && QX11Info::isPlatformX11()) {
         if (!startup_id.isEmpty() && startup_id != "0") {
             NETRootInfo i(QX11Info::connection(), NET::Supported);
             if (i.isSupported(NET::WM2StartupId)) {
@@ -735,17 +810,17 @@ KStartupInfo::startup_t KStartupInfo::checkStartup(WId w_P, KStartupInfoId &id_O
 
 KStartupInfo::startup_t KStartupInfo::checkStartup(WId w_P, KStartupInfoId &id_O)
 {
-    return d->check_startup_internal(w_P, &id_O, NULL);
+    return d->check_startup_internal(w_P, &id_O, nullptr);
 }
 
 KStartupInfo::startup_t KStartupInfo::checkStartup(WId w_P, KStartupInfoData &data_O)
 {
-    return d->check_startup_internal(w_P, NULL, &data_O);
+    return d->check_startup_internal(w_P, nullptr, &data_O);
 }
 
 KStartupInfo::startup_t KStartupInfo::checkStartup(WId w_P)
 {
-    return d->check_startup_internal(w_P, NULL, NULL);
+    return d->check_startup_internal(w_P, nullptr, nullptr);
 }
 
 KStartupInfo::startup_t KStartupInfo::Private::check_startup_internal(WId w_P, KStartupInfoId *id_O,
@@ -761,18 +836,18 @@ KStartupInfo::startup_t KStartupInfo::Private::check_startup_internal(WId w_P, K
     //  - No - Is this a NET_WM compliant app ?
     //           - Yes - test for pid match
     //           - No - test for WM_CLASS match
-    qDebug() << "check_startup";
+    qCDebug(LOG_KWINDOWSYSTEM) << "check_startup";
     QByteArray id = windowStartupId(w_P);
     if (!id.isNull()) {
         if (id.isEmpty() || id == "0") { // means ignore this window
-            qDebug() << "ignore";
+            qCDebug(LOG_KWINDOWSYSTEM) << "ignore";
             return NoMatch;
         }
         return find_id(id, id_O, data_O) ? Match : NoMatch;
     }
 #if KWINDOWSYSTEM_HAVE_X11
     if (!QX11Info::isPlatformX11()) {
-        qDebug() << "check_startup:cantdetect";
+        qCDebug(LOG_KWINDOWSYSTEM) << "check_startup:cantdetect";
         return CantDetect;
     }
     NETWinInfo info(QX11Info::connection(),  w_P, QX11Info::appRootWindow(),
@@ -809,24 +884,24 @@ KStartupInfo::startup_t KStartupInfo::Private::check_startup_internal(WId w_P, K
         return NoMatch;
     }
 #endif
-    qDebug() << "check_startup:cantdetect";
+    qCDebug(LOG_KWINDOWSYSTEM) << "check_startup:cantdetect";
     return CantDetect;
 }
 
 bool KStartupInfo::Private::find_id(const QByteArray &id_P, KStartupInfoId *id_O,
                                     KStartupInfoData *data_O)
 {
-    //qDebug() << "find_id:" << id_P;
+    //qCDebug(LOG_KWINDOWSYSTEM) << "find_id:" << id_P;
     KStartupInfoId id;
     id.initId(id_P);
     if (startups.contains(id)) {
-        if (id_O != NULL) {
+        if (id_O != nullptr) {
             *id_O = id;
         }
-        if (data_O != NULL) {
+        if (data_O != nullptr) {
             *data_O = startups[ id ];
         }
-        //qDebug() << "check_startup_id:match";
+        //qCDebug(LOG_KWINDOWSYSTEM) << "check_startup_id:match";
         return true;
     }
     return false;
@@ -835,21 +910,21 @@ bool KStartupInfo::Private::find_id(const QByteArray &id_P, KStartupInfoId *id_O
 bool KStartupInfo::Private::find_pid(pid_t pid_P, const QByteArray &hostname_P,
                                      KStartupInfoId *id_O, KStartupInfoData *data_O)
 {
-    //qDebug() << "find_pid:" << pid_P;
+    //qCDebug(LOG_KWINDOWSYSTEM) << "find_pid:" << pid_P;
     for (QMap< KStartupInfoId, KStartupInfo::Data >::Iterator it = startups.begin();
             it != startups.end();
             ++it) {
         if ((*it).is_pid(pid_P) && (*it).hostname() == hostname_P) {
             // Found it !
-            if (id_O != NULL) {
+            if (id_O != nullptr) {
                 *id_O = it.key();
             }
-            if (data_O != NULL) {
+            if (data_O != nullptr) {
                 *data_O = *it;
             }
             // non-compliant, remove on first match
             removeStartupInfoInternal(it);
-            //qDebug() << "check_startup_pid:match";
+            //qCDebug(LOG_KWINDOWSYSTEM) << "check_startup_pid:match";
             return true;
         }
     }
@@ -861,22 +936,22 @@ bool KStartupInfo::Private::find_wclass(const QByteArray &_res_name, const QByte
 {
     QByteArray res_name = _res_name.toLower();
     QByteArray res_class = _res_class.toLower();
-    //qDebug() << "find_wclass:" << res_name << ":" << res_class;
+    //qCDebug(LOG_KWINDOWSYSTEM) << "find_wclass:" << res_name << ":" << res_class;
     for (QMap< KStartupInfoId, Data >::Iterator it = startups.begin();
             it != startups.end();
             ++it) {
         const QByteArray wmclass = (*it).findWMClass();
         if (wmclass.toLower() == res_name || wmclass.toLower() == res_class) {
             // Found it !
-            if (id_O != NULL) {
+            if (id_O != nullptr) {
                 *id_O = it.key();
             }
-            if (data_O != NULL) {
+            if (data_O != nullptr) {
                 *data_O = *it;
             }
             // non-compliant, remove on first match
             removeStartupInfoInternal(it);
-            //qDebug() << "check_startup_wclass:match";
+            //qCDebug(LOG_KWINDOWSYSTEM) << "check_startup_wclass:match";
             return true;
         }
     }
@@ -889,11 +964,11 @@ QByteArray KStartupInfo::windowStartupId(WId w_P)
     if (!QX11Info::isPlatformX11()) {
         return QByteArray();
     }
-    NETWinInfo info(QX11Info::connection(), w_P, QX11Info::appRootWindow(), 0, NET::WM2StartupId | NET::WM2GroupLeader);
+    NETWinInfo info(QX11Info::connection(), w_P, QX11Info::appRootWindow(), nullptr, NET::WM2StartupId | NET::WM2GroupLeader);
     QByteArray ret = info.startupId();
     if (ret.isEmpty() && info.groupLeader() != XCB_WINDOW_NONE) {
         // retry with window group leader, as the spec says
-        NETWinInfo groupLeaderInfo(QX11Info::connection(), info.groupLeader(), QX11Info::appRootWindow(), 0, NET::WM2StartupId);
+        NETWinInfo groupLeaderInfo(QX11Info::connection(), info.groupLeader(), QX11Info::appRootWindow(), nullptr, NET::WM2StartupId);
         ret = groupLeaderInfo.startupId();
     }
     return ret;
@@ -912,7 +987,7 @@ void KStartupInfo::setWindowStartupId(WId w_P, const QByteArray &id_P)
     if (id_P.isNull()) {
         return;
     }
-    NETWinInfo info(QX11Info::connection(), w_P, QX11Info::appRootWindow(), 0, 0);
+    NETWinInfo info(QX11Info::connection(), w_P, QX11Info::appRootWindow(), nullptr, nullptr);
     info.setStartupId(id_P.constData());
 #else
     Q_UNUSED(w_P)
@@ -1010,7 +1085,7 @@ QByteArray KStartupInfo::createNewStartupIdForTimestamp(quint32 timestamp)
     tm.tv_sec = msecsSinceEpoch / 1000;
     tm.tv_usec = (msecsSinceEpoch % 1000) * 1000;
 #else
-    gettimeofday(&tm, NULL);
+    gettimeofday(&tm, nullptr);
 #endif
     char hostname[ 256 ];
     hostname[ 0 ] = '\0';
@@ -1019,7 +1094,7 @@ QByteArray KStartupInfo::createNewStartupIdForTimestamp(quint32 timestamp)
     }
     QByteArray id = QString::fromLatin1("%1;%2;%3;%4_TIME%5").arg(hostname).arg(tm.tv_sec)
                     .arg(tm.tv_usec).arg(getpid()).arg(timestamp).toUtf8();
-    //qDebug() << "creating: " << id << ":" << (qApp ? qAppName() : QString("unnamed app") /* e.g. kdeinit */);
+    //qCDebug(LOG_KWINDOWSYSTEM) << "creating: " << id << ":" << (qApp ? qAppName() : QString("unnamed app") /* e.g. kdeinit */);
     return id;
 }
 
@@ -1051,7 +1126,7 @@ void KStartupInfoId::initId(const QByteArray &id_P)
     if (!id_P.isEmpty()) {
         d->id = id_P;
 #ifdef KSTARTUPINFO_ALL_DEBUG
-        qDebug() << "using: " << d->id;
+        qCDebug(LOG_KWINDOWSYSTEM) << "using: " << d->id;
 #endif
         return;
     }
@@ -1060,7 +1135,7 @@ void KStartupInfoId::initId(const QByteArray &id_P)
         // already has id
         d->id = startup_env;
 #ifdef KSTARTUPINFO_ALL_DEBUG
-        qDebug() << "reusing: " << d->id;
+        qCDebug(LOG_KWINDOWSYSTEM) << "reusing: " << d->id;
 #endif
         return;
     }
